function adjacencyMatrix = linkTable2adjacencyMatrix(linkTable, N)

    % Compute the adjacency matrix from a link table of a multi-digraph
    %
    % Syntax: adjacencyMatrix = linkTable2adjacencyMatrix(linkTable, N)
    %
    % Input parameters:
    % - linkTable (Ex2): A table in which each row represents
	%   the origin and the destination nodes of the link
    % - N: Number of nodes in the topology
    %
    % Output parameters:
    % - adjacencyMatrix (NxN): An sparse matrix in which each position
    %   a_ij represents the number of links between nodes i and j

	%% Sanity checks
	assert(numel(N) == 1 && isfinite(N) && N > 0 && N == floor(N), 'N must be greater than 0');
	
	if isempty(linkTable)
		adjacencyMatrix = zeros(N,N);
	else
		assert(isLinkTable(linkTable, N), 'A valid set of links is required');

		%% Compute adjacency matrix
		adjacencyMatrix = accumarray(linkTable, 1, [N N], [], [], true);
	end

end